@@ -14,10 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -32,9 +30,10 @@
 #include "seahorse-pgp-key.h"
 
 #include "seahorse-common.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
-#include "seahorse-passphrase.h"
+
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-util.h"
+#include "libseahorse/seahorse-passphrase.h"
 
 #include <gcr/gcr.h>
 
@@ -47,7 +46,7 @@
 #include <locale.h>
 
 #define DEBUG_FLAG SEAHORSE_DEBUG_OPERATION
-#include "seahorse-debug.h"
+#include "libseahorse/seahorse-debug.h"
 
 enum {
 	PROP_0,
