@@ -15,21 +15,21 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
+#include "seahorse-keyserver-results.h"
+
 #include "seahorse-pgp-backend.h"
 #include "seahorse-gpgme-keyring.h"
 #include "seahorse-keyserver-search.h"
-#include "seahorse-keyserver-results.h"
 
-#include "seahorse-key-manager-store.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-key-manager-store.h"
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <glib/gi18n.h>
 
